#
# spec file for package sg3_utils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sg3_utils
Version:        1.48+9.ecc03bb
%global lname libsgutils2-%(echo %{version} | sed 's/[~+].*//;y/./_/')-2
Release:        1.2
Summary:        A collection of tools that send SCSI commands to devices
License:        BSD-3-Clause AND GPL-2.0-or-later
Group:          Hardware/Other
URL:            http://sg.danny.cz/sg/sg3_utils.html
Source:         sg3_utils-%{version}.tar.gz
Source1:        dracut.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libtool
BuildRequires:  systemd-rpm-macros
BuildRequires:  xz
Requires(post): coreutils
Provides:       scsi = %{version}
Provides:       sg_utils
Supplements:    modalias(scsi:t-0x00*)
Supplements:    modalias(scsi:t-0x07*)
Supplements:    modalias(scsi:t-0x0e*)
Obsoletes:      scsi <= 1.7_2.38_1.25_0.19_1.02_0.93
# For regenerate_initrd_posttrans
%if 0%{?suse_version} < 1550
BuildRequires:  suse-module-tools
%else
BuildRequires:  rpm-config-SUSE
%endif

%description
The sg3_utils package contains utilities that send SCSI commands to
devices. As well as devices on transports traditionally associated with
SCSI (e.g. Fibre Channel (FCP), Serial Attached SCSI (SAS) and the SCSI
Parallel Interface(SPI)) many other devices use SCSI command sets.
ATAPI cd/dvd drives and SATA disks that connect via a translation layer
or a bridge device are examples of devices that use SCSI command sets.

%package -n %lname
Summary:        Library to hold functions common to the SCSI utilities
License:        BSD-3-Clause
Group:          System/Libraries

%description -n %lname
The sg3_utils package contains utilities that send SCSI commands to
devices. As well as devices on transports traditionally associated with
SCSI (e.g. Fibre Channel (FCP), Serial Attached SCSI (SAS) and the SCSI
Parallel Interface(SPI)) many other devices use SCSI command sets.
ATAPI cd/dvd drives and SATA disks that connect via a translation layer
or a bridge device are examples of devices that use SCSI command sets.

This subpackage contains the library of common sg_utils code, such as
SCSI error processing.

%package -n libsgutils-devel
Summary:        A collection of tools that send SCSI commands to devices
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
# Added for 13.1
Obsoletes:      %name-devel < %version-%release
Provides:       %name-devel = %version-%release

%description -n libsgutils-devel
The sg3_utils package contains utilities that send SCSI commands to
devices. As well as devices on transports traditionally associated with
SCSI (e.g. Fibre Channel (FCP), Serial Attached SCSI (SAS) and the SCSI
Parallel Interface(SPI)) many other devices use SCSI command sets.
ATAPI cd/dvd drives and SATA disks that connect via a translation layer
or a bridge device are examples of devices that use SCSI command sets.

This subpackage contains libraries and header files for developing
applications that want to make use of libsgutils.

%prep
%setup -q

%build
autoreconf -fi
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
install -m 644 doc/rescan-scsi-bus.sh.8 %{buildroot}/%{_mandir}/man8
mkdir -p %{buildroot}/%{_udevrulesdir}
install -m 644 scripts/00-scsi-sg3_config.rules %{buildroot}/%{_udevrulesdir}
install -m 644 scripts/40-usb-blacklist.rules %{buildroot}/%{_udevrulesdir}
install -m 644 scripts/54-before-scsi-sg3_id.rules %{buildroot}/%{_udevrulesdir}
install -m 644 scripts/55-scsi-sg3_id.rules %{buildroot}/%{_udevrulesdir}
install -m 644 scripts/58-scsi-sg3_symlink.rules %{buildroot}/%{_udevrulesdir}
install -m 644 scripts/59-fc-wwpn-id.rules %{buildroot}/%{_udevrulesdir}
install -m 755 scripts/fc_wwpn_id %{buildroot}/%{_udevrulesdir}/..
mkdir -p %{buildroot}/usr/lib/dracut/dracut.conf.d
install -m 644 %{SOURCE1} %{buildroot}/usr/lib/dracut/dracut.conf.d/50-sg3_utils.conf
mkdir -p %{buildroot}/%{_unitdir}
install -m 644 scripts/lunmask.service %{buildroot}/%{_unitdir}
mkdir -p %{buildroot}/%{_unitdir}/../scripts
install -m 755 scripts/scsi-enable-target-scan.sh %{buildroot}/%{_unitdir}/../scripts
rm -f %{buildroot}%{_libdir}/*.la

%post -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%pre
%service_add_pre lunmask.service

%post
%service_add_post lunmask.service
%{?regenerate_initrd_post}

%preun
%service_del_preun lunmask.service

%postun
%service_del_postun lunmask.service
%{?regenerate_initrd_post}

%posttrans
%{?regenerate_initrd_posttrans}

%files
%defattr(-,root,root)
%doc README README.sg_start
%doc ChangeLog CREDITS NEWS
%_bindir/sg_*
%_bindir/scsi_*
%_bindir/sginfo
%_bindir/sgp_dd
%_bindir/sgm_dd
%_bindir/rescan-scsi-bus.sh
%_mandir/man8/*.8*
%dir /usr/lib/udev
%dir %{_udevrulesdir}
%{_udevrulesdir}/00-scsi-sg3_config.rules
%{_udevrulesdir}/40-usb-blacklist.rules
%{_udevrulesdir}/54-before-scsi-sg3_id.rules
%{_udevrulesdir}/55-scsi-sg3_id.rules
%{_udevrulesdir}/58-scsi-sg3_symlink.rules
%{_udevrulesdir}/59-fc-wwpn-id.rules
%{_udevrulesdir}/../fc_wwpn_id
%dir /usr/lib/dracut
%dir /usr/lib/dracut/dracut.conf.d
/usr/lib/dracut/dracut.conf.d/50-sg3_utils.conf
%dir %{_unitdir}/../scripts
%{_unitdir}/../scripts/scsi-enable-target-scan.sh
%{_unitdir}/lunmask.service

%files -n %lname
%defattr(-,root,root)
%_libdir/libsgutils2-1.*.so.2*

%files -n libsgutils-devel
%defattr(-,root,root)
%_libdir/libsgutils2.so
%_includedir/scsi/

%changelog
* Fri Apr 19 2024 Martin Wilck <mwilck@suse.com>
- sg_inq: re-add Unit serial number field (bsc#1219547)
* Tue Feb 13 2024 Martin Wilck <mwilck@suse.com>
- Fix missing SCSI_MODEL and other fields for "sg_inq --export"
  (bsc#1219874)
* Tue Jan  9 2024 Martin Wilck <mwilck@suse.com>
- Fix spurious warning for non-SCSI devices (boo#1218666)
* Mon Jan  8 2024 Martin Wilck <mwilck@suse.com>
- Upstream bug fixes for sg3_utils 1.48 (bsc#1218591)
  * sg_turs: fix missing CDB on several codepaths
  * sg_dd: fix bug that identified all block devices as NVME
  * rescan-scsi-bus.sh: avoid root FS going read-only with
    "rescan-scsi-bus.sh -r" (gh#doug-gilbert/sg3_utils#46)
* Fri Oct 20 2023 Martin Wilck <mwilck@suse.com>
- rescan-scsi-bus.sh: remove /tmp/rescan-scsi-mpath-info.txt
  (gh#doug-gilbert/sg3_utils#44)
* Mon Oct 16 2023 Martin Wilck <mwilck@suse.com>
- rescan_scsi_bus.sh: fix multipath issue when called with -s and
  without -u (bsc#1215720, bsc#1216355)
* Thu Sep 28 2023 Martin Wilck <mwilck@suse.com>
- udev rules: allow kernel command line overrides with
  "udev.scsi_id_serial_src=LTVS" and "udev.scsi_symlink_src=LTVS"
  Try these boot parameters if your system fails to detect SCSI
  devices after update to sg3_utils 1.48.
* Wed Sep 27 2023 Martin Wilck <mwilck@suse.com>
- dracut.conf: add 00-scsi-sg3_config.rules (jsc#PED-6226)
- spec file:
  * fix build dependencies for regenerate_initrd_posttrans
  (bsc#1215772)
  * add missing rules file
* Thu Sep 21 2023 Martin Wilck <mwilck@suse.com>
- Update to version 1.48
  * udev rules: new, configurable scheme for creating symlinks for SCSI devices
    (jsc#PED-6226)
    See description of ".SCSI_ID_SERIAL_SRC" /usr/lib/udev/55-scsi-sg3_id.rules
    and .SCSI_SYMLINK_SRC in /usr/lib/udev/58-scsi_symlink.rules
  * decoding utilities: add -j/--json[=JO] and --js-file=JFN options
  * sg_sat_datetime: new tool to access date/time on ATA devices using a SAT layer
  * sg_z_act_query: new tool for sending zone activate/query commands
  * sg_rem_rest_elem: new tool for removing or restoring elements
  * sg_write_attr: support for SPC "Write Attirbute" command (for tapes)
  * sg_ses: swap meaning of -H and -HH, add json support, use e.g.
    "0:2" for range indicator
  * sg_rtpg: fix response truncation
  * sg_decode_sense: add --nodecode option
  * sg_logs: fix --list and -lll options
  * sg_modes: improve handling of ZBC disks
  * sg_inq: add version descriptors from SPC6r08, add --quiet option
  * sg_vpd: add --sinq_inraw=RFN option
  * sg_turs: add --timeout= and --ascq= options
  * sg_requests: add --timeout= option
  * sg_sat_read_gplog: add --smart and --ppt options
  * sgp_dd and sgm_dd: add --progress option
  * sg_dd: add support for accessing NVMe devices via passthrough
  * Bug fixes and minor fixes
- _service: simplify version processing, as we have a clean upstream version again
* Fri Jan 27 2023 Martin Wilck <mwilck@suse.com>
- Update to version 1.48~20221101+1.142dace:
  * fix output of "sg_inq -H -p bdc" (boo#1207700)
* Thu Nov  3 2022 mwilck@suse.com
- Update to new upstream version 1.48~20221101.6d3bd26:
  (pre-release sg3_utils-1.48 [20221101] [svn: r978])
  * sg_read_block_limits: fix granularity value, add --mloi option
  * sg_lib: add sg_ll_read_block_limits_v2(); sg_logs: json work
  * sg_stream_ctl: --get fix better; sg_rem_rest_elem: cleanup
  * sg_stream_ctl: fix --get indexing; fix some './configure --enable-debug' issues
  * sg_inq+sg_vpd: JSON updates
  * rescan-scsi-bus: speed large multipath scans (bsc#1207706)
  * rescan-scsi-bus.sh speed testonline()
  * rescan-scsi-bus.sh: add option --no-lip-scan
  * rescan-scsi-bus: sgdevice26: do not traverse sg class if scsi_device isnot added
  * rescan-scsi-bus.sh: fix handling of '-I <secs>' option
  * Prepare for removing /proc/scsi from the Linux kernel
  * sg_inq+sg_vpd: merge VPD page processing
  * sg_get_elem_status: change '--maxlen=' option default to 1056 (was 32), other cleanups
  * sg_rep_zones: add experimental --json[=JO] option and generation
  * sg_logs: add --exclude and --undefined options
  * zoned disk man page improvements
  * sg_rep_zones: add --statistics option
  * sg_read_buffer: add --eh_code= and --no_output options
  * sg_format: allow disk formats on ZBC (zoned) disks
  * sg_rep_zones: add --brief option and --find ZT option
  * sg_rep_density: new utility for decoding the response of Report density support command [ssc (tape)]
  * Zoned block device characteristics VPD page support
* Wed Jun  1 2022 mwilck@suse.com
- Update to version 1.47+5.d13bc56:
  * rescan-scsi-bus.sh: add timeout parameter (bsc#1199248)
* Mon Feb 21 2022 mwilck@suse.com
- Update to version 1.47+4.82fb156:
  * rescan_scsi_bus.sh: restore numeric ordering of hosts (bsc#1196244)
* Tue Feb  8 2022 mwilck@suse.com
- Update to version 1.47+3.adb7276:
  * rescan-scsi-bus.sh: fix garbled output (bsc#1195621)
* Tue Jan  4 2022 mwilck@suse.com
- Update to version 1.47+2.388b767:
  * rescan-scsi-bus.sh: apply fix for '-r' (boo#1194293)
  * _service: use openSUSE github repo again (with cherry-picks
    from upstream)
  * spec file: suppress commit ID in library version
* Thu Nov 11 2021 mwilck@suse.com
- Update to version 1.47:
  * sg_rep_zones: add support for REPORT ZONE DOMAINS and
    REPORT REALMS in this utility
  * sg_raw: fix prints of NVMe NVM command names
  * sg_logs: additions to Volume statistics lpage [ssc5r05c]
  - additions to Command duration limits statistics log
    page [spc6r06]
  * sg_vpd: fix do_hex type on some recent pages
  - zoned block dev char vpd: add zone alignment mode and
    zone starting LBA granularity [zbc2r11]
  * sg_read_buffer: fix --length= problem
  * sg_dd, sgm_dd, sgp_dd: don't close negative file descriptors
  * sg_dd: srand48_r() and mrand48_r() are GNU libc specific,
    put conditional in so non-reentrant version used otherwise
  - 'iflag=00,ff' places the 32 bit block address (big endian)
    into each block
  * sgp_dd: major rework, fix issue with error being ignored
  - new: --chkaddr which checks for block address in each block
  - add check for stdatomic.h presence in configure.ac
  * sg_xcopy: tweak CSCD identification descriptor
  * sg_get_elem_status: fix issue with '--maxlen=' option
  - add 2 depopulation revocation health attributes [sbc5r01]
  * transport error handling improved. To fix report of a
    BAD_TARGET transport error but the utility still continued.
  - introduce SG_LIB_TRANSPORT_ERROR [35] exit status
  * several utilities: override '--maxlen=LEN' when LEN
    is < 16 (or 4), take default (or 4) instead
  * scripts: 55-scsi-sg3_id.rules remove outdated rule (bsc#1189297)
  * sg_lib: add sg_scsi_status_is_good(),
    sg_scsi_status_is_bad() and sg_get_zone_type_str()
  * pt_linux: fix verify(BytChk=0) which Linux SNTL translated
    to write, other SNTL cleanups
  * pt_linux_nvme: fix fua setting
  * pt: check_pt_file_handle() add return value of 5 for
- _service updates:
  * re-enable service, hadn't been used for 1.46 release
  * use upstream author's git repository, simplify versioning scheme
  * use obscpio format
* Tue Apr 20 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to version 1.46:
  * sg_rep_pip: new utility: report provisioning initialization
    pattern command
  * sg_turs: estimated time-to-ready [spc6r03]
  - add --delay=MS option
  * sg_requests: substantial cleanup
  * sg_vpd: add Format presets and Concurrent positioning ranges
  - add hot-pluggable field in standard Inquiry [spc6r05]
  - fix vendor struct opts_t alignment
  * sg_inq: add hot-pluggable field in standard Inquiry
  * sg_dd: --verify : separate category for miscompare errors
  - --verify : oflag=coe continue on miscompares, counts them
  - add cdl= operand for command duration limit indexes
  - add oflag=nocreat and conv=nocreat : OFILE must exist
  - add iflag=00, ff, random flags
  - setup conditional auto rule for getrandom()
  - add command timeout after comma in time= operand
  * sg_get_elem_status: add ralwd bit sbc4r20a
  * sg_write_x: add dld bits to write(32) [sbc4r19a]
  * sg_rep_zones: print invalid write pointer LBA as -1 rather
    than 16 "f"s
  * sg_opcodes: improve handling of RWCDLP field
  * sg_ses: use fan speed factor field for calculation [ses4r04]
  - add --all (-a) option, same action as --join
  * sg_compare_and_write: add examples section to its manpage
  * sg_modes: document '-s' option (same as '-6')
  * sg_sanitize + sg_format: when --verbose given once report
    probable success; without --verbose 'no news is good news'
  * sg_zone: add Remove element and modify zones command
  * sg_raw: increase maximum data-in and data-out buffer size
    from 64 KB to 1 MB
  - fix --cmdfile= handling
  - add --nvm option to send commands from the NVM command set
  - add --cmdset option to bypass cdb heuristic
  - add --scan= first_opcode,last_opcode
  * sg_pt_freebsd: allow device names without leading /dev/
    thus fix for regression introduced in rev 731 (ver: 1.43)
  * sg_pt_solaris+sg_pt_osf1: fix problem with clear_scsi_pt_obj()
    which needs to remember is_nvme and dev_fd values
  * sg_lib: add ZBC (2020) feature set entries
  * sg_lib: restore elements and rebuild command added
  * sg_lib,sg_pt: add partial_clear_scsi_pt_obj(),
    get_scsi_pt_cdb_len() and get_scsi_pt_cdb_buf()
  - add do_nvm_pt() for the NVM (sub-)command set
  - tweak transport error handling in Linux
  * sg_lib: Linux NVMe SNTL: add read, write and verify;
    synchronize cache and write same translations
  - add dummy start stop unit and test unit ready commands
  - wire cache mpage's WCE to nvme 'volatile write cache'
  - fix crash in sg_f2hex_arr() when fname not found
  * sg_lib: reprint cdb with illegal request sense key
  - asc/ascq match asc-num.txt @t10 20200708 [spc6r02]
  * gcc-10: suppress warnings
  * autoconf: upgrade version 2.69 to 2.70
  * remove space from end of source lines for git-svn
  * testing/sg_mrq_testing: new, for blocking mrq usage
  * testing/sgs_dd: add evfd flags and eventfd processing
  * testing: remove master-slave terminology for sgv4
  * examples: add nvme_read_ctl.hex and nvme_write_ctl.hex
- Earlier SUSE fixes included in 1.46:
  * 40-usb-blacklist.rules: use ID_SCSI_INQUIRY
    (bsc#840054, bsc#1131482)
* Thu Apr 25 2019 mwilck@suse.com
- Update to version 1.45~815+5.6aa67ed:
  * 59-fc-wwpn-id.rules: fix rule syntax (bsc#1133418)
- Update to svn r815:
  * sg_opcodes: expand MLU (spc5r20)
  * sg_inq: update version descriptors to spc5r21
  * sg_vpd: 3pc VPD page add copy group descriptor
  * sg_xcopy: add --fco (fast copy only) (spc5r20) and --app=1
  * add nanosecond durations with SG3_UTILS_LINUX_NANO
- Earlier SUSE fixes now included upstream:
  * 58-scsi-sg3_symlink.rules: don't skip multipath members
  (bsc#1085212) [r815]
  * rescan-scsi-bus.sh: terminate scanning if last lun got removed
  (bsc#1087008) [r815]
  * Add scsi-enable-target-scan.sh (bsc#954600) [r814]
  * shellcheck cleanups for rescan-scsi-bus.sh [r814]
* Thu Apr 18 2019 Jan Engelhardt <jengelh@inai.de>
- Replace old $RPM_* shell vars.
* Tue Mar 26 2019 mwilck@suse.com
- Spec file:
  * add fc_wwpn_id (bsc#1005063)
  * add lun masking service (bsc#954600)
  * drop BuildRequires on udev
  * replace unversioned "Provides: scsi" with versioned
- Update to version sg3_utils-1.45~803+31.564be3d:
  * New versioning scheme for upstream pre-release:
    1.45 - upstream release target, 803 - upstream svn id,
    +31: SUSE commits on top of svn, 564be3d - git hash
  * rescan-scsi-bus.sh: terminate scanning if last lun got removed
  (bsc#1087008)
  * 58-scsi-sg3_symlink.rules: don't skip multipath members
  (bsc#1085212)
  * Add scsi-enable-target-scan.sh (bsc#954600)
- Update to svn r803:
  * sg_opcodes: expand MLU (18-102r0)
  * sg_format: add --dcrt used twice (FOV=1 DCRT=0)
  * rescan-scsi-bus: widen LUN 0 only scanning
  (bsc#1069384)
- Earlier SUSE fixes included in 1.45:
  * rescan-scsi-bus.sh: use LUN wildcard in idlist (bsc#1069384)
  [svn: r795]
  * sg_ses: fixup page decoding (bsc#1077787) [svn: r795]
  * sg_ses: allow to decode raw data instead of reading from a device
  (bsc#1050943) [svn: r795]
- Update to sg3_utils-1.44 [20180912] [svn: r791]
  * rescan-scsi-bus.sh: harden code
  - bump version to 20180615
  - add --ignore-rev to ignore revision change
  * introduce SG3_UTILS_DSENSE environment variable
  * sginfo: don't open /dev/snapshot
  * sg_timestamp: add '--no-timestamp' option
  - add --elapsed and --hex options
  * sg_wr_mode: add --rtd option for RTD bi
  * sg_unmap: add --all=ST,RN[,LA] option
  * sgm_dd, sg_dd: add --dry-run and --verbose options
  * sg_inq+sg_vpd: update Extended inquiry data vpd page
  * sg_ses: add 'hw_reset' and 'sw_reset' to enclosure services
    controller electronics element type (18-047r1)
  * sg_decode sense: add --cdb and --err=ES options
  * sg_format: add --dry-run option
  - extend --wait timeout for > 4TB disks
  * sg_sanitize: add --dry-run option
- Earlier SUSE fixes included in 1.44:
  * sg_inq: decode standard INQUIRY for CD-ROMs correctly
  (bsc#1065448, bsc#1070431) [svn: r742]
  * sg_inq: export all NAA values (bsc#1050767) [svn: r715]
  * Add fc_wwpn_id to generate by-path links for fibrechannel
  (bsc#1005063) (svn@715)
  * sg_vpd: struct opts_t misaligment (bsc#1050943) [svn: r707]
* Fri Apr  6 2018 hare@suse.de
- Update to svn r763:
  * More NVMe bugfixes
  * sg_vpd: add device constituents vpd
  * sg_raw: add --raw option
  * sg_turs: add --low option
  * sg_ses: decoding dpage fixes; add --quiet option
- rescan-scsi-bus.sh: Fixup syntax error (bsc#1087008)
- rescan-scsi-bus.sh: Fixes from shellcheck
* Mon Feb 12 2018 mwilck@suse.com
- dracut.conf: add whitespace at end of line (bsc#1080562)
* Fri Feb  9 2018 hare@suse.de
- Update to svn r751:
  * NVMe bugfixes
  * sg_seek: new utility
  * sg_stream_ctl: new utility program
- 54-before-scsi-sg3_id.rules: compability rule for systemd
  (bsc#1079873)
- Add dracut.conf to install new rule with dracut
* Thu Feb  8 2018 hare@suse.de
- Merge local patch with git repository
  * Delete sgut-libversioning.diff
* Wed Feb  7 2018 hare@suse.de
- Update to svn r744:
  * sg_write_x: new command for normal/atomic/orwrite etc
    SCSI WRITE variants
  * sg_ses: add NVMe support
  * sg_inq: decode NVMe controller / NSIDs
- rescan_scsi_bus.sh: Fix manpage for --forcerescan
- 55-scsi-sg3_id.rules: fixes for scsi_id compability (bsc#1079873)
- 55-scsi-sg3_id.rules: run sg_inq for SPC devices (bsc#1079873)
* Fri Dec 22 2017 hare@suse.de
- sg_inq: check VPD page 0x0 before reading serial number
  (bsc#1067839)
- sg_inq: add option '-o/--only' to skip reading VPD pages
  (bsc#1067839)
- Revert 'postun' rpm spec changes after review
* Mon Dec 18 2017 hare@suse.de
- sg_inq: decode standard INQUIRY for CD-ROMs correctly (bsc#1070431)
- rescan-scsi-bus.sh: new option for ignore rev change
- rescan-scsi-bus.sh: Remove white space
- Add 'coreutils' to Requires (bsc#1072744)
- Add 'posttrans' to rpm spec (bsc#1071972)
* Wed Nov 29 2017 hare@suse.de
- Update to svn r730:
  * Move testing utilities to 'testing' directory
  * sg_opcode: check resid and trim response
  * sg_rep_zones: expand --help option
  * sg_mode: Add Out-of-band management control page
  * sg_ses: filer join output on dpage element presence
  * documentation cleanup
- rescan-scsi-bus.sh: Add '--ignore-rev' option
- Supplement SCSI modaliases (bsc#1065212)
* Fri Oct 13 2017 hare@suse.de
- Update to svn r721:
  * Merge SUSE-specific patches with upstream svn
  * sg_write_atomic: add new program for WRITE ATOMIC
  * sg_bg_ctl: new background control command
  * sg_ses: Improve output and option handling
  * sg_logs: Add --vendor and decode more pages
  * sg_get_lba_status: add new program
  * Install rescan-scsi-bus.sh and scsi_logging_level per default
* Fri Aug 11 2017 hare@suse.de
- Drop patch merged with git repository
  * drop add-lunsearch-filter-to-searchexisting.patch
- Drop rules included in git repository
  * drop 40-usb-blacklist.rules
- Update to latest svn snapshot:
  * sg_rdac: add sanity checks for -f=lun value
  * sg_vpd improvements
  * sg_ses: fix uninitialized struct
  * sg_luns: resync with SAM and SPC drafts
  * sg_vpd: fix struct misalignment introduced by --force
  * sg_logs: add --vendor and fixup enumeration
- Port patches from SLES:
  * Add systemd service files for LUN masking (bsc#954600)
  * 55-scsi-sg3_id.rules: handle VPD page 0x80 correctly (bsc#1006469)
  * scripts: added udev rules for legacy CCISS (bsc#1006175)
  * rescan-scsi-bus.sh: Add lunsearch filter to findresized()
  (bsc#1027176)
  * Add fc_wwpn_id to generate by-path links for fibrechannel
  (bsc#1005063)
  * 55-scsi-sg3_id.rules: allow to override sysfs inquiry
  (bsc#1012523)
  * sg_inq: export all NAA values (bsc#1050767)
  * Silence gcc warnings
* Mon Feb 20 2017 kukuk@suse.de
- Remove superfluous insserv PreReq.
* Wed Sep  7 2016 sparschauer@suse.de
- using "--lun" now works correctly (bsc#981452), adding patch:
  * add-lunsearch-filter-to-searchexisting.patch
* Fri Apr 29 2016 hare@suse.de
- Update to new upstream release 1.43:
  * sg_senddiag: add --timeout=SEC option
  * sg_sanitize: add --timeout=SEC option
  * sg_format: add --timeout=SEC option
  * sg_decode sense: add --cdb option
  * sg_ses: handle 2 bit EIIOE field in aes dpage
  - expand join handling of SAS connectors and others
  - expand join debug code
  * sg_logs: fix volume statistics lpage when subpage
    is zero (ssc5r02a); decode mount history log parameter
  - decode Requested recovery, TapeAlert response, and
    Service buffer information lpages for tape
  - add '--pdt=DT' option
  * sg_inq: fix potential unbounded loop in --export
  - update version descriptor list to 20160420
  * sg_inq+sg_vpd: update Extended inquiry data vpd
    page (spc5r09)
  - add --force option to bypass checking supported
    vpd pages page and fetch requested page directly
  * sg_reassign+sg_write_same: fix ULONG_MAX problem
  * sg_turs+sg_requests: make both accept '--num=NUM'
    and '--number=NUM' for mutual compatibility
  * sg_zone: fix debug cdb naming
  * sg_opcode: add '--enumerate' and '--pdt=' options
  * sg_raw: add '--enumerate' option
  * sg_lib: add SSC maintenance in/out sa names
  - add read buffer(16) command mode names
  - add sg_decode_transportid_str()
  * sg_lib_data: sync asc/ascq codes with T10 20160425
  * rescan-scsi-bus.sh: harden code
  * clang --analyze static checker clean ups
  * shellcheck cleanup on scripts
  * automake: add AM_PROG_AR to configure.ac
  - upgrade to version 1.15
- Include patches from upstream:
  * sg_inq+sg_vpd: add --force option to bypass checking
    of supported vpd pages
  * sg_lib_data: add Bind and Unbind to service action out(16)
- Remove 0001-sg_vpd-sg_inq-Safe-VPD-page-access.patch; merged
  with upstream.
* Thu Apr 28 2016 hare@suse.de
- sg_inq,sg_vpd: Safe VPD page access (bsc#945094)
  * Add 0001-sg_vpd-sg_inq-Safe-VPD-page-access.patch
* Thu Feb 18 2016 hare@suse.de
- Update to new upstream release 1.42:
  * sg_timestamp: new, to report or set timestamp
  * sg_read_attr: new, supported by tape drives
  * sg_stpg: fix truncation of target port field
  * sg_inq: cope with unicode strings, udev fixes
  - update version descriptor list to 20160125
  - '--export': new entries for UUID descriptor
  * sg_ses: add more field acronyms (ses3r11)
  8 sg_logs: add Utilization lpage (sbc4r07)
  - add Background operation lpage
  - add Pending defects lpage
  - add LPS misalignment lpage (sbc4r10)
  - document '--All' ('-A') option
  - rework lto tape vendor lpages
  * sg_vpd: add Block limits extension VPD page
  - add Device constituents VPD page
  - add LB Protection VPD page (ssc 15-296r1)
  - LB provisioning VPD page: expand LBPRZ, add
    Minimum and Threshold percentage fields
  - rework lto tape vendor VPD pages
  * sg_inq+sg_vpd+sg_xcopy: add support for locally
    assigned UUIDs in VPD page 0x83 (15-267r2)
  * sg_sanitize: add --znr option (sbc4r07)
  * sg_rep_zones: add --partial option (zbc-r04)
  * sg_format: add ffmt option (sbc4r10)
  - add support for FORMAT MEDIUM (for tape)
  * sg_raw: document length relationships
  * rescan-scsi-bus.sh: updates from Suse
  * sg_lib_data: sync asc/ascq codes with T10 20151126
  * sg_lib: add 'sense' categories for SCSI statuses:
    condition met, busy, task set full, ACA active and
    task aborted
  - add pr2serr() extern
  - change sg_get_sense_str() and dStrHexStr(), return
    chars written (returned void previously)
  - add sg_get_sense_descriptors_str() function
  - add sg_get_designation_descriptor_str() function
  - sg_get_desig_type_str()+sg_get_desig_assoc_str()
    and sg_get_desig_code_set_str() added
  - sg_get_opcode_sa_name() break out zoning in/out,
    read attribute and read position service actions
  * sg_cmds_extra: add sg_ll_format_unit2() for FFMT
  * sg_pr2serr.h: new, to shorten fprintf(stderr, ...)
  * sg_io_linux, sg_pt_linux: drop SUGGEST_* decoding
  * sg_unaligned.h: add 48 bit support and gets for
    variable length unsigned integers
- Delete sg3_utils-sg_inq-blacklist.diff; solved differently
- Added 40-usb-blacklist.rules (bsc#840054)
- Delete sg3_utils-58-scsi-sg3_symlink-fixup.patch;
  merged with upstream
- Delete sg3_utils-flush-fixup.patch; merged with upstream
* Mon Nov 16 2015 m4mnux@gmail.com
- Add sg3_utils-flush-fixup.patch: Fix syntax error when -f (flush
  failed multipath devices) used in command line.
* Mon Oct  5 2015 zaitor@opensuse.org
- Add sg3_utils-58-scsi-sg3_symlink-fixup.patch: Fix broken line in
  script (boo#940833, boo#940834, boo#947947).
* Wed Jul  8 2015 jthumshirn@suse.com
- Update to new upstream release 1.41
  * sg_zone: new utility for open, close and finish
    zone commands introduced in zbc-r02
  * sg_rep_zones and sg_reset_wp: change opcodes as
    indicated in zbc-r02
  * sg_read_buffer: add READ BUFFER(16) support (spc5r02)
  * sg_logs: add --enumerate and acronyms
  * allow decode from hex or binary in file
  * decode environmental reporting + limits lpages
  * sg_write_buffer: add --timeout=TO option
  * sg_lib interface: add sg_lib_pdt_decay(), TPROTO_PCIE
    plus support for zoning service actions
  * sg_lib: in Linux blocked devices yield ENXIO from
    ioctl(SG_IO), map to SG_LIB_CAT_NOT_READY
  * clean up sg_warnings_stream handling
  * sg_inq+sg_vpd: fix SCSI name string decoding in
    device identification VPD page (0x83)
  * increase sanity on Unit Serial number VPD page
  * improve rdac vpd page reporting (vendor)
  * sg_inq: improve NAA handling in dev_id VPD page
  * update version descriptor list to 20150126
* Fri Feb 13 2015 jengelh@inai.de
- Update to ne wupstream release 1.40
  * New utilities: sg_write_verify (for WRITE AND VERIFY),
  sg_ses_microcode, sg_sat_read_gplog.
  * sg_senddiag gained the --maxlen= and --page=PG options
  * sg_opcodes gained the --compact field
  * sg_inq: expand Block limits VPD page output
- Drop sg3_utils-fix-missing-rule-for-scsi_serial-partitions.patch,
  sg3_utils-Fixup-formatting-of-invalid-VPD-page-0x83.patch,
  sg3_utils-Do-not-export-long-identifiers.patch
  (merged upstream)
- Replace symbol version hack (it forced lockstep updates) by
  sgut-libversioning.diff (allows parallel installation).
* Sun Jan  4 2015 lnussel@suse.de
- blacklist some usb controllers that don't like sg_inq (bnc#840054)
  Add: sg3_utils-sg_inq-blacklist.diff
* Wed Sep  3 2014 hare@suse.de
- Fixup formatting of invalid VPD pages (bnc#884779)
  Add: sg3_utils-Fixup-formatting-of-invalid-VPD-page-0x83.patch
- sg_inq: Do not export long identifiers (bnc#884779)
  Add: sg3_utils-Do-not-export-long-identifiers.patch
* Wed Jun 25 2014 rmilasan@suse.com
- Fix missing rule for generating links for partitions also (bnc#883032)
  Add:
  sg3_utils-fix-missing-rule-for-scsi_serial-partitions.patch
* Fri Jun 20 2014 jengelh@inai.de
- Add symbol versions to library
* Tue Jun 17 2014 jengelh@inai.de
- Update to new upstream release 1.39
  * This release adds some ZBC support in the form of sg_rep_zones
  and sg_reset_wp.
  * It tracks changes made by www.t10.org since April 2014.
- Remove
  0001-Split-59-scsi-sg_utils.rules-for-multipath-support.patch,
  0003-sg_inq-compability-links-for-ata_id.patch,
  0004-sg_inq-suppress-warning-messages-for-export.patch,
  sginfo-inq-fields-strip-blank.patch (merged upstream).
* Thu May 15 2014 hare@suse.de
- Create compability links for ATA devices (bnc#876344)
  Add:
  0003-sg_inq-compability-links-for-ata_id.patch
- Suppress warnings for sg_inq --export (bnc#876454)
  Add:
  0004-sg_inq-suppress-warning-messages-for-export.patch
* Tue Apr 15 2014 spargaonkar@suse.com
- added patch sginfo-inq-fields-strip-blank.patch
  sg3_utils: Strip out trailing info from vendor info products fields in inq
  bnc#863357
- added patches:
  * sginfo-inq-fields-strip-blank.patch
* Fri Apr 11 2014 hare@suse.de
- Split off 59-scsi-sg_utils.rules to properly support
  multipathing (bnc#873151)
  Remove:
  0001-59-scsi-sg_utils.rules-skip-symlinks-for-multipath-d.patch
  Add:
  0001-Split-59-scsi-sg_utils.rules-for-multipath-support.patch
* Thu Apr 10 2014 hare@suse.de
- Update to official release 1.38
  * Update documentation
  * Update to latest SPC
  * Minor fixes
  * Add: sg3_utils-1.38.tar.xz
  * Remove: sg3_utils-1.38b7r538.tar.xz
  * Remove: sg3_utils-1.38r546.patch
  * Remove: sg3_utils-1.38b12r556.patch
- Use 59-scsi-sg3_utils from the rpm
  Remove: 59-scsi-sg3_utils.rules
- Fixup 59-scsi-sg3_utils.rules to not provide symlinks
  on multipath device paths (bnc#872929)
  Add: 0001-59-scsi-sg_utils.rules-skip-symlinks-for-multipath-d.patch
* Fri Mar  7 2014 hare@suse.de
- Fixup 59-scsi_sg3_utils.rules to provide compability links
  for ata_id (bnc#866933)
* Fri Feb 28 2014 hare@suse.de
- Add 59-scsi-sg3_utils.rules (bnc#865494)
* Tue Feb 25 2014 hare@suse.de
- Update to inofficial release 1.38b12r556 (bnc#865494)
  * Add --inhex parameter to sg_inq
  * sg_inq: decode ASCII information vpd page
  * sg_inq: allow page=-1 to force std INQUIRY decoding
  * sg_inq: improve unit serial number display
  * sg_vpd: Add LTO and DDS vendor pages
  * sg_persist: add SOP transport ID
  * sg_lib_data: sync asc/ascq code with T10
  * rescan-scsi-bus.sh: check if FC driver exports issue_lip
  * Add man page for rescan-scsi-bus.sh
- Remove sg3_utils-check-if-hba-supports-issue-lip.patch,
  has been merged with upstream
* Thu Jan 23 2014 hare@suse.de
- Update to inofficial release 1.38r546 (bnc#831778)
  * sg_ses: error and warning message cleanup
  - fix --data=- problem with large buffers
  - new --data=@FN to read hex data from file FN
  - add --maxlen= option
  * sg_inq:
  - add LU_CONG to standard inquiry response
  - sync version descriptors dated 20131126
  - fix overflow in encode_whitespaces
  * sg_vpd: add LU_CONG to standard inquiry response output
  - decode Third Party Copy (tpc) page
  * sg_persist: add PROUT: Replace Lost Reservation (spc4r36)
  * sg_readcap: for --16 show physical block size if
  * sg_xcopy:
  - environment variables: XCOPY_TO_SRC and
    XCOPY_TO_DST indicate where xcopy command is sent
  - change default to send xcopy to dst (was src)
  - improve CL handling of short options (e.g. '-vv')
  * sg_write_same: repeat if unit attention
  * sg_rtpg: fix indexing bug with --extended option
  * sg_lib_data: sync asc/ascq codes with T10 dated 20131110
  * sg_cmds_extra: fix sa bug in sg_ll_3party_copy_out()
- Update tarball to 1.38b7r537
- Add sg3_utils-1.38r546.patch
* Mon Nov  4 2013 jengelh@inai.de
- Update to new upstream release 1.37
  * sg_compare_and_write: add --quiet option to suppress miscompare
  report
  * sg_persist: fix core dump on -Q option
  * sg_unmap: fix core dump on -g option
  * sg_ses: add --nickname and --nickid options
- Remove sg3_utils-Fixup-T10-Vendor-designator-display.patch
  (merged upstream)
* Sun Aug 25 2013 ohering@suse.de
- Fixup T10 Vendor designator display (bnc#805059)
  sg3_utils-Fixup-T10-Vendor-designator-display.patch
- In rescan-scsi-bus.sh, check if the HBA driver exports issue_lip
  in sysfs before using it (bnc#780946)
  sg3_utils-check-if-hba-supports-issue-lip.patch
* Thu Jun 13 2013 jengelh@inai.de
- Implement shlib packaging guidelines; rename sg3_utils-devel
  to libsgutils-devel (upstream recommendation)
- More robust make install call; remove redundant %%clean section;
  simplify file lists
* Tue Jun 11 2013 rmilasan@suse.com
- Update to version 1.36
  - sg_vpd: Protocol-specific port information VPD page
    for SAS SSP, persistent connection (spl3r2), power
    disable (spl3r3)
  - block device characteristics: add FUAB bit
  - sg_xcopy: handle more descriptor types; handle zero
    maximum segment length; allow list IDs to be disabled;
    improve skip/seek handling; allow xcopy on destination
  - sg_reset: and --no-esc option to stop reset escalation
  - clean up cli, add long option names
  - sg_luns: add --test=ALUN option for decoding LUNs
  - decoded luns output in decimal or hex (if -HH given)
  - add '--linux' option to show Linux LUN after T10
    representation, can map one to the other
  - sg_inq: add --vendor option to show standard inquiry's
    vendor specific fields in ASCII
  - take resid into account with response output
  - sg_sync: add --16 (for 16 byte command) and --timeout=
  - sg_logs: add data compression page (ssc4)
  - sg_sat_set_features: increase --lba from 1 to 4 bytes
  - sg_write_same: add --ndob option (sbc3r35d)
  - sg_map: mark as deprecated
  - sginfo: mark as deprecated, especially -l (list)
  - sg_lib: improve snprintf handling
  - sg_lib_data: sync asc/ascq codes with T10 20130117
  - sg_cmds (lib): if noisy given, give more UA info
  - make code more C++ friendly
* Tue Mar 12 2013 hare@suse.de
- Update to version 1.35
  - sg_compare_and_write: new utility
  - sg_inq+sg_vpd: block device characteristics VPD page:
    add product_type, WABEREQ, WACEREQ and VBULS fields
  - sg_inq: more --export option changes for udev
  - sg_vpd: add more rdac vendor specific vpd pages
  - sg_verify: add --ebytchk option for sbc3r34 changes
  - sg_stpg: --offline option: fix 'Invalid state 0xe'
  - sg_ses: Door Lock element changed to Door element and
    abbreviation changed from 'dl' to 'do' (ses3r05)
  - archive/rescan-scsi-bus.sh: upgrade to version 1.53hr
  - move rescan-scsi-bus.sh to scripts directory
  - sync to sbc3r34
  - sg_lib: sg_ll_verify10+16 expand BYTCHK to 2 bit field
  - sg_pt_win32, sg_scan(win32): changes for cygwin 1.7.17
  - clean up man page summary lines
  - sg_xcopy: new dd like utility for extended copy command
  - sg_copy_results: new utility for receive copy results
  - sg_verify: add 16 byte cdb, bytchk (data-out buffer)
    and group number support
  - sync to spc4r36 and sbc3r32
  - sg_inq: add --export so sg_inq can replace udev's scsi_id
  - decode old EMC Symmetrix abuse of VPD page 0x83
  - sg_vpd: decode old EMC Symmetrix abuse of VPD page 0x83
  - sg_ses: increase max dpage response size to 64 KB
  - allow ident,locate on enclosure controller
  - more sanity for additional element status descriptor
  - sg_sanitize: add --ause, --fail and --test=
  - sg_luns: add long extended flat space addressing format
  - sg_logs: add ATA pass-through results lpage (SAT-2)
  - sg_rtpg: add --extended option
  - sg_senddiag: list rebuild assist diag page name
  - sg_pt_linux: expand DID_ (host_byte) codes
  - cope with a transport error plus sense data
  - prefer major() over MAJOR() macro
  - sg_lib: fix sg_get_command_name() service actions
  - report sdat_ovfl bit (if set) in sense data
  - decode extended_copy and receive_copy service actions
  - decode read_buffer and write_buffer modes
  - decode ATA PT fixed format sense (SAT-2)
  - sg_cmds_extra: add sg_ll_report_tgt_prt_grp2()
  - ./configure options:
  - change --enable-no-linux-bsg to --disable-linuxbsg
  - add --disable-scsistrings to reduce utility sizes
* Wed Jul  4 2012 cfarrell@suse.com
- license update: GPL-2.0+ and BSD-3-Clause
  Show aggregation and make compatible with Fedora declaration
* Sun Apr 22 2012 puzel@suse.com
- Update to version 1.33
  - sg_ses: major rework of indexes (again), now two level
  - sg_write_buffer: new --specific option for mode specific
    field; new mode 13 (spc4r32)
  - sg_vpd: add hp3par volume info vendor VPD page
  - fix 'scsi ports' [0x88] page problem
  - add 'sinq' pseudo page for standard inquiry response
  - add power consumption page
  - sg_format: add --poll= option for request sense polling
  - improve handling of disks > 2 TB and DIF (protection)
  - sg_logs: LB provision lpage extra (sbc3r28)
  - sg_modes: application tag mpage subcode 0xf0->0x2
  - sg_write_same: no prot fields when wrprotect=0
  - sg_get_lba_status: reflect change in sbc3r25 to Parameter
    Data Length response field (offset reduced from 8 to 4)
  - sg_inq, sg_vpd: sync with spc4r33
  - win32: change DataBufferOffset type per MSDN; caused
    problem with 64 bit machines (with buffered interface)
  - sg_luns: tweak documentation for vendor specific reports
  - add man pages for scsi_loging_level, scsi_mandat,
    scsi_satl and scsi_temperature
* Mon Jan 16 2012 tabraham@novell.com
- Update to version 1.32
  + sg_sanitize: new utility for command added in sb3r27
  + sg_sat_identify: add '--ident' to output WWN
  + sg_ses: major rework of descriptor output
    + add --index, --descriptor, --join, --clear, --get, and --set
    options
  + sg_raw: exit status corrections
  + sg_decode_sense: add --nospace and --hex options
  + sg_logs: fix bug with large --maxlen
    + zero response length when resid implies it is invalid
    + add scope field to lb provisioning lpage (sb3r27)
  + sg_inq: sync version descriptors with spc4r31
  + sb_lib_data: sync asc/ascq codes with spc4r31
  + sg_vpd: add LBPRZ field in LP provisioning VPD page
  + sg_format: allow format of pdt 7 (some MO drives)
  + sg_cmd_basic: sg_cmds_process_resp() handle status good
    with a sense key other than no_sense (e.g. completed)
  + add README.iscsi
- Updated rescan-scsi-bus.sh to v1.56
* Thu Mar 10 2011 coolo@novell.com
- fix file list
* Fri Feb 18 2011 hare@suse.de
- Update to version 1.31:
  + sg_decode_sense: new utility to decode sense data
  + sg_vpd: LB provisioning + Block limits pages (sbc3r26)
  + sync asc/ascq and version descriptors with spc4r28
  + sg_get_config, sg_rmsn, sg_verify: add --readonly option
  + sg_lib: implement forwarded sense data descriptor
  - decode user data segment referral sense data descriptor
  + sg_lib, sg_turs, sg_format: more precision for progress
    indication (two places after decimal point)
  + sg_lib(win32): add runtime selection of SPT direct or
    indirect interface
  - sg_read_buffer+sg_write_buffer: set SPT direct
  + add examples/forwarded_sense.txt + examples/ref_sense.txt
- Changes from version 1.30:
  + sg_referrals: new utility for REPORT REFERRALS
  + sbc3r25 renames 'thin' provisioning' to 'logical block
    provisioning': changes in sg_format, sg_inq, sg_logs,
    sg_modes, sg_readcap, sg_vpd
  + sg_inq: update version descriptor list to spc4r27
  - extended inquiry vpd page add extended self test
    completion minutes field
  + sg_lib: sync asc/ascq list to spc4r27
  - dStrHex(): trim excess trailing spaces
  + sg_read_long: add --readonly option (open() is rw)
  + sg_raw: add --readonly option (open() is rw)
  - allow bidirectional commands
  + sg_vpd: rdac vendor page [0xc8] parse corrections
  - extended inquiry vpd page add extended self test
  - completion minutes field
  + sg_ses: expand --data (in) buffer to 2048 bytes
  + sg_opcodes: add extended parameter data for TMFs (spc4r26)
  + sg_dd: clean count calculation, document nocache flag
  - treat bsg devices as implicit sg_io
  + sg_write_same: if READ CAPACITY(16) fails try 10 byte variant
  - anticipate approval of proposal to allow UNMAP and ANCHOR
    bits to be set on WRITE SAME(10) with '--10' option
  + sg3_utils man page: sections added for OS device names
* Fri Aug 13 2010 dimstar@opensuse.org
- Update to version 1.29:
  + sg_rtpg: new logical block dependent state and bit (spc4r23)
  + sg_start: add '--readonly' option for ATA disks
  + sg_lib: update asc/ascq list to spc4r23
  + sg_inq: update version descriptor list to spc4r23
  + sg_vpd: block device characteristics page: fix form factor
  - update Extended Inquiry VPD page to spc4r23
  - update Block Limits VPD page to sbc3r22
  - update Thin Provisioning VPD page to sbc3r22
  - Automation device serial number and Data transfer device
    element VPD pages (ssc4r01)
  - add Referrals VPD page (sbc3r22)
  + sg_logs: add thin provisioning and solid state media log pages
  - addition of IBM LTO specific log pages
  + sg_modes: new page names from ssc4r01
  + sg_ses: sync with ses3r02 (SAS-2.1 connector types)
  + sg_unmap: add '--anchor' option (sbc3r22)
  + sg_write_same: add '--anchor' option (sbc3r22)
  + sg_pt interface: add set_scsi_pt_flags() to permit passing
    through SCSI_PT_FLAGS_QUEUE_AT_TAIL and AT_HEAD flags
  + add examples/sg_queue_tst+bsg_queue_tst for SG_FLAG_Q_AT_TAIL
  + add AM_MAINTAINER_MODE to configure.ac to lessen build issues
  + add BSD_LICENSE file to this and lib directories, refer to
    it from source and header files. Some source has GPL license
- Changes from version 1.28:
  + sg_unmap: new utility for thin provisioning
  - add examples/sg_unmap_example.txt
  + sg_get_lba_status: new utility for thin provisioning
  + sg_read_block_limits: new utility for tape drives
  + sg_logs: add cache memory statistics log (sub)page
  + sg_vpd, sg_inq: extend Block limits VPD page (sbc3r19)
  + sg_vpd: add Thin provisioning VPD page (sbc3r20) and
    TapeAlert supported flags VPD page
  + sg_inq: note VPD page support better in sg_vpd
  + sg_persist: add transport specific transportID format
  - allow transportIDs to be read from named file
  + sg_opcodes: allow --opcode= option to take OP and SA
    values (comma seperated)
  - tweak print format, remove test code
  + sg_requests: remove test code in progress calculation
  + sg_reset: add target reset option
  + sg_luns: reduce default maxlen to 8192 (for FreeBSD)
  + sg_raw: extend max cdb length from 16 to 256 bytes
  - align heap allocs to page boundaries
  + sg_lib: sg_set_binary_mode() needs config.h included
  - add progress indication sense data descriptor (0xa)
  - change SG3_UTILS_* constants to SG_LIB_*
  - decode service actions within persistent reserve in/out
  - sync with spc4r21
  + sg_cmds_extra: add sg_ll_unmap() and sg_ll_get_lba_status()
  + sg_pt_linux: fix check condition but empty sense buffer;
  - major() macro grief, if present include <linux/kdev_t.h> and
    use MAJOR() instead
  + scripts/sas_disk_blink: moved from this package to sdparm
  + utils/hxascdmp: in Windows set binary mode on read files
  + examples/sg_persist_tst.sh: add PRIN read full status command
  + sg_raw,sg_write_buffer,sg_write_long,sg_write_same: in Windows
    set binary mode on read files
  + sg_pt_win32: default to non-direct variant of SPT interface
  - use './configure --enable-win32-spt-direct' to override
  - non-direct data length set to 16 KB, extended if required
  + debian: incorporate patch from debian sid
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Tue Jul 21 2009 hare@suse.de
- Clean up spec file and remove obsolete cruft
* Fri Apr 17 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Mon Jan 26 2009 hare@suse.de
- Fixes to rescan-scsi-bus.sh:
  * Implement '--forcerescan' to force a rescan of existing devices
  * Handle LUN changes correctly
  * Check variables before evaluation
* Wed Oct 29 2008 garloff@suse.de
- rescan-scsi-bus.sh 1.29:
  * Fix error in script (returning "" does not work)
  * Support systems without /proc/scsi
- Don't install INSTALL
* Tue Sep 30 2008 hare@suse.de
-  Add %%insserv_prereq (bnc#423204)
* Fri Sep 12 2008 garloff@suse.de
- Update rescan-scsi-bus.sh script to 1.28:
  * Merge fixes from Hannes
  * Minor cleanups
  * Sort hosts numerically
* Tue Aug 12 2008 garloff@suse.de
- Update to sg3_utils-1.27:
  * Adapted to linux-2.6.26 (sg_map26)
  * sg_dd uses flock (rw -- if that fails ro)
  * sg_get_config: OSSC feature (mmc6r02)
- Update to sg3_utils-1.26:
  * Minor fixes and enhancements to
    sg_sat_phy_event, sg_ses, sg_get_config, sg_verify, sg_vpd,
    sg_inq, sg_modes, sg_start, sg_request, sg_luns, sg_dd,
    sg_opcodes, sg_turs.
  * sg_lib: asc/ascq update for spc4r15, osd2r03 service actions,
    sense key specific unit attn queue overflow decoding, ...
  * Restructuring: sg_lib -> sg_lib_data, sg_inq_data, (u)int64_t,
    sg_io_linux -> lib/.
  * Documentation enhancements.
* Wed Jul 16 2008 hare@suse.de
- Use correct length parameter for sg_inq (bnc#363438)
* Fri May 23 2008 hare@suse.de
- Use 'Provides' to clean update dependency
* Fri May  9 2008 schwab@suse.de
- Use autoreconf -i.
* Thu Apr 24 2008 hare@suse.de
- Split off from original scsi package.
